package com.flossom.system.service;

import com.flossom.common.core.domain.entity.WxParameterSetting;

import java.util.List;

/**
 * 微信参数配属Service接口
 *
 * @author flossom
 * @date 2023-12-13
 */
public interface IWxParameterSettingService {
    /**
     * 查询微信参数配属
     *
     * @param id 微信参数配属主键
     * @return 微信参数配属
     */
    public WxParameterSetting selectWxParameterSettingById(Long id);

    /**
     * 查询微信参数配属列表
     *
     * @param wxParameterSetting 微信参数配属
     * @return 微信参数配属集合
     */
    public List<WxParameterSetting> selectWxParameterSettingList(WxParameterSetting wxParameterSetting);

    /**
     * 新增微信参数配属
     *
     * @param wxParameterSetting 微信参数配属
     * @return 结果
     */
    public int insertWxParameterSetting(WxParameterSetting wxParameterSetting);

    /**
     * 修改微信参数配属
     *
     * @param wxParameterSetting 微信参数配属
     * @return 结果
     */
    public int updateWxParameterSetting(WxParameterSetting wxParameterSetting);

    /**
     * 批量删除微信参数配属
     *
     * @param ids 需要删除的微信参数配属主键集合
     * @return 结果
     */
    public int deleteWxParameterSettingByIds(Long[] ids);

    /**
     * 删除微信参数配属信息
     *
     * @param id 微信参数配属主键
     * @return 结果
     */
    public int deleteWxParameterSettingById(Long id);
}
